<?php

/**
 * @file
 * Admin forms to configure account credentials.
 */

/**
 * Generic settings form.
 */
function freeagent_settings() {
  $form = array();
  $form['freeagent_client_id'] = array(
    '#type' => 'textfield',
    '#title' => t('Your FreeAgent app client id'),
    '#required' => TRUE,
    '#default_value' => variable_get('freeagent_client_id', ''),
  );
  $form['freeagent_secret'] = array(
    '#type' => 'textfield',
    '#title' => t('Your FreeAgent app client secret'),
    '#required' => TRUE,
    '#default_value' => variable_get('freeagent_secret', ''),
  );

  $form['verify'] = array(
    '#type' => 'markup',
    '#markup' => freeagent_admin_access_token(),
  );

  $data_types = array(
    'timeslips' => t('Timeslips'),
    'expenses' => t('Expenses'),
    'invoices' => t('Invoices'),
    'bills' => t('Bills'),
  );
  $form['freeagent_fetch_data_types'] = array(
    '#type' => 'checkboxes',
    '#options' => $data_types,
    '#title' => t('Additional data to fetch'),
    '#description' => t('By default, the integration will fetch contacts, projects and tasks. Here you can choose additional data to retrieve from FreeAgent.'),
    '#default_value' => variable_get('freeagent_fetch_data_types', array()),
  );

  $form['freeagent_purge_all_data'] = array(
    '#type' => 'checkbox',
    '#title' => t('Purge all data'),
    '#default_value' => FALSE,
  );

  $form['freeagent_refresh_all_data'] = array(
    '#type' => 'checkbox',
    '#title' => t('Refresh all data'),
    '#description' => t('All data is refreshed, including old data, and not just new records retrieved. This may take some time.'),
    '#default_value' => FALSE,
  );

  $form = system_settings_form($form);

  $form['actions']['submit']['#value'] = t('Save');
  $form['actions']['submit']['#submit'][] = 'freeagent_settings_submit';

  $form['actions']['authorise'] = array(
    '#type' => 'submit',
    '#value' => t('Authorise'),
    '#submit' => array('freeagent_settings_authorise_submit'),
  );

  $form['actions']['refresh'] = array(
    '#type' => 'submit',
    '#value' => t('Refresh data'),
    '#submit' => array('freeagent_settings_refresh_data_submit'),
  );

  return $form;
}

/**
 * Display message about authorisation.
 */
function freeagent_admin_access_token() {
  $access_token = variable_get('freeagent_access_token', '');
  if (!empty($access_token)) {
    $message = t('Your FreeAgent access token is: @token', array('@token' => $access_token));
  }
  else {
    $message = t('Not successfully authorised yet.');
  }
  
  return '<p>' . $message . '</p>';
}

/**
 * Submit handler for freeagent_settings() to authorise the app.
 */
function freeagent_settings_submit(&$form, &$form_state) {
  drupal_set_message(t('Your settings have been saved.'));
  $data_types = $form_state['values']['freeagent_fetch_data_types'];
  variable_set('freeagent_fetch_data_types', $data_types);

  if (!empty($form_state['values']['freeagent_purge_all_data'])) {
    freeagent_purge_data();
    drupal_set_message(t('All data has been deleted.'));
  }
  else {
    $purge_types = array();
    foreach ($data_types as $type => $keep) {
      if (empty($keep)) {
        $purge_types[] = $type;
      }
    }
    if (!empty($purge_types)) {
      freeagent_purge_data($purge_types);
    }
  }

  if (!empty($form_state['values']['freeagent_refresh_all_data'])) {
    freeagent_refresh_data(86400);
  }
}

/**
 * Submit handler for freeagent_settings() to authorise the app.
 */
function freeagent_settings_authorise_submit(&$form, &$form_state) {
  $form_state['redirect'] = freeagent_authorise(NULL, FALSE);
  $access_token = variable_get('freeagent_access_token', '');
  if (!empty($access_token)) {
    $time = time();
    $success = freeagent_refresh_data(NULL);
    if ($success) {
      variable_set('freeagent_last_cron_run', $time);
    }
  }
}

/**
 * Submit handler for freeagent_settings() to refresh data.
 */
function freeagent_settings_refresh_data_submit(&$form, &$form_state) {
  // Refreshes ALL data, including older data.
  if (!empty($form_state['values']['freeagent_refresh_all_data'])) {
    freeagent_refresh_data(86400);
  }
  // Only pull down the latest data since the last refresh.
  else {
    freeagent_refresh_data(0);
  }
}

/**
 * Helper function to show the access level description.
 */
function freeagent_access_level($access_id) {
  switch ($access_id) {
    case 0:
      return t('No access');
    case 1:
      return t('Time Tracking');
    case 2:
      return t('My Money');
    case 3:
      return t('Contacts and Projects');
    case 4:
      return t('Estimates and Invoices');
    case 5:
      return t('Bills');
    case 6:
      return t('Banking');
    case 7:
      return t('Tax and Limited Accounting');
    case 8:
      return t('Full Access');
  }
}

